@@ -1,8 +1,8 @@
 import os
 
-from src.sigla.lib.Nodes.Node import Node
-from src.sigla.lib.helpers.files import ensure_parent_dir
-from src.sigla.lib.helpers.Context import Context
+from sigla.lib.Nodes.Node import Node
+from sigla.lib.helpers.files import ensure_parent_dir
+from sigla.lib.helpers.Context import Context
 
 
 class NodeFile(Node):
